#
# spec file for package terraform
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%global provider        github
%global provider_tld    com
%global project         terraform-providers
%global repo            terraform-provider-local
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global registry        registry.terraform.io
%global namespace       hashicorp
%global providername    local

%ifarch aarch64
%define terraformarch   amd64
%endif
%ifarch ppc64
%define terraformarch   ppc64
%endif
%ifarch ppc64le
%define terraformarch   ppc64le
%endif
%ifarch s390x
%define terraformarch   s390x
%endif
%ifarch %{ix86}
%define terraformarch   i386
%endif
%ifarch x86_64
%define terraformarch   amd64
%endif

%if 0%{?suse_version}
%{go_nostrip}
%endif

Name:           terraform-provider-local
Version:        2.0.0
Release:        6.3.1
License:        MPL-2.0
Summary:        Terraform local-provider
Url:            https://github.com/terraform-providers/terraform-provider-local
Group:          System/Management
Source:         %{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.12
Requires:       terraform >= 0.12.0
%if 0%{?suse_version}
%{go_provides}
%endif

%description
This is a terraform provider that lets you use local files

%prep
%setup -q -n %{repo}-%{version}

%build
export GO111MODULE=off
export GOPROXY=off
%if 0%{?suse_version}
%goprep %{import_path}
%gobuild
%endif
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version} || 0%{?ubuntu_version}
mkdir -p ./_build/src/github.com/terraform-providers
ln -s $(pwd) ./_build/src/github.com/terraform-providers/terraform-provider-local
export GOPATH=$(pwd)/_build
cd _build/src/github.com/terraform-providers/terraform-provider-local
go build -ldflags "-X main.version=%{version}" .
%endif

%install
export GO111MODULE=off
export GOPROXY=off
%if 0%{?suse_version}
%goinstall
rm -rf %{buildroot}/%{_libdir}/go/contrib
%endif
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version} || 0%{?ubuntu_version}
export GOPATH=$(pwd)/_build
mkdir -p %{buildroot}%{_bindir}
export GOBIN=%{buildroot}%{_bindir}
cd _build/src/github.com/terraform-providers/terraform-provider-local
go install -ldflags "-X main.version=%{version}"
%endif
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}_v%{version}
install -d 755 %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}
ln -s %{_bindir}/%{name} %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}/%{name}_v%{version}

curr=$PWD
# extract the binary to be published
if [ -d %{_topdir}/OTHER ]; then
    cd %{buildroot}%{_bindir}
    tar zcf %{_topdir}/OTHER/%{name}-%{version}.%{_repository}.%{_arch}.tar.gz %{name}
fi
cd $curr

%files
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/%{name}
%{_bindir}/%{name}_v%{version}
%{_datadir}/terraform

%changelog
* Wed Nov 11 2020 adrian.glaubitz@suse.com
- Add symbolic link to comply with new filesystem layout for local provider copies
- Define and use common Go spec file variables
* Tue Oct 20 2020 adrian.glaubitz@suse.com
- Update to version 2.0.0
  BREAKING CHANGES:
  * Upgrade to version 2 of the Terraform Plugin SDK, which drops support
    for Terraform 0.11. This provider will continue to work as expected for
    users of Terraform 0.11, which will not download the new version. (#42)
  NEW FEATURES:
  * Add `source` attribute to `local_file` resource (#44)
* Fri Feb  7 2020 rjschwei@suse.com
- Create symlink for terraform to recognize the provider. See
  https://www.terraform.io/docs/extend/how-terraform-works.html#plugin-locations
* Wed Feb  5 2020 adrian.glaubitz@suse.com
- Update to version 1.4.0
  NOTES:
  * The provider has switched to the standalone TF SDK, there should be
    no noticeable impact on compatibility.
    ([#32](https://github.com/terraform-providers/terraform-provider-local/issues/32))
  NEW FEATURES:
  * r/local_file: allow for configurable permissions
    ([#30](https://github.com/terraform-providers/terraform-provider-local/issues/30))
- from version 1.3.0
  * Add support for base64 encoded content
    ([#29](https://github.com/terraform-providers/terraform-provider-local/issues/29))
- Include CHANGELOG.md in %%doc section
- Increase golang API in BuildRequires to > 1.12
- Increase terraform version dependency to > 0.12.0
* Fri May 17 2019 fbergmann@suse.com
- Initial packaging of the local terraform provider
